@@ -6,12 +6,12 @@ import functools
 import json
 import typing
 from collections.abc import Iterator, Mapping, MutableSequence
-from typing import Any, Literal
+from typing import Any, Literal, TypedDict
 
 import npc_session
 import upath
 import yaml
-from typing_extensions import TypeAlias
+from typing_extensions import NotRequired, TypeAlias, Unpack
 
 import npc_lims.exceptions as exceptions
 import npc_lims.metadata.codeocean as codeocean
@@ -80,7 +80,7 @@ class SessionInfo:
     @functools.cached_property
     def behavior_day(self) -> int | None:
         if self.is_templeton:
-            raise AttributeError("`behavior_day` is not defined for Templeton sessions")
+            return None  # not accessible for Templeton sessions
         return self.training_info.get("ID")  # row of training spreadsheet
 
     @functools.cached_property
@@ -89,8 +89,9 @@ class SessionInfo:
         CodeOcean. Not the same as `cloud_path` being non-None: this property
         indicates a proper session upload via aind tools, with metadata etc.
 
-        >>> next(session.is_uploaded for session in get_session_info() if session.is_uploaded)
-        True
+        Examples:
+            >>> next(session.is_uploaded for session in get_session_info() if session.is_uploaded)
+            True
         """
         if not self.is_ephys:
             return False  # currently only ephys sessions are uploaded to AIND-codeocean
@@ -103,8 +104,10 @@ class SessionInfo:
         """The session has ephys data collected separately to record surface
         channel.
 
-        >>> get_session_info("DRpilot_660023_20230808").is_surface_channels
-        True
+        Examples:
+
+            >>> get_session_info("DRpilot_660023_20230808").is_surface_channels
+            True
         """
         if self.session_kwargs.get("probe_letters_with_surface_channel_recording"):
             return True
@@ -114,13 +117,87 @@ class SessionInfo:
             return False
         return True
 
+    @functools.cached_property
+    def is_dlc_eye(self) -> bool:
+        """
+        The dlc eye capsule has yield a result for this session
+        >>> get_session_info("676909_2023-12-13").is_dlc_eye
+        True
+        """
+
+        if not self.is_ephys:
+            return False
+
+        try:
+            return bool(
+                codeocean.get_session_capsule_pipeline_data_asset(self.id, "dlc_eye")
+            )
+        except (FileNotFoundError, ValueError):
+            return False
+
+    @functools.cached_property
+    def is_dlc_side(self) -> bool:
+        """
+        The dlc side capsule has yield a result for this session
+        >>> get_session_info("676909_2023-12-13").is_dlc_side
+        True
+        """
+
+        if not self.is_ephys:
+            return False
+
+        try:
+            return bool(
+                codeocean.get_session_capsule_pipeline_data_asset(self.id, "dlc_side")
+            )
+        except (FileNotFoundError, ValueError):
+            return False
+
+    @functools.cached_property
+    def is_dlc_face(self) -> bool:
+        """
+        The dlc face capsule has yield a result for this session
+        >>> get_session_info("676909_2023-12-13").is_dlc_face
+        True
+        """
+
+        if not self.is_ephys:
+            return False
+
+        try:
+            return bool(
+                codeocean.get_session_capsule_pipeline_data_asset(self.id, "dlc_face")
+            )
+        except (FileNotFoundError, ValueError):
+            return False
+
+    @functools.cached_property
+    def is_facemap(self) -> bool:
+        """
+        The facemap capsule has yield a result for this session
+        >>> get_session_info("676909_2023-12-13").is_facemap
+        True
+        """
+
+        if not self.is_ephys:
+            return False
+
+        try:
+            return bool(
+                codeocean.get_session_capsule_pipeline_data_asset(self.id, "facemap")
+            )
+        except (FileNotFoundError, ValueError):
+            return False
+
     @functools.cached_property
     def is_sorted(self) -> bool:
         """The AIND sorting pipeline has yielded a Result asset for this
         session.
 
-        >>> next(session.is_sorted for session in get_session_info() if session.is_sorted)
-        True
+        Examples:
+
+            >>> next(session.is_sorted for session in get_session_info() if session.is_sorted)
+            True
         """
         if not self.is_ephys:
             return False
@@ -138,8 +215,10 @@ class SessionInfo:
         """The subject associated with the sessions has CCF annotation data for
         probes available on S3.
 
-        >>> next(session.is_annotated for session in get_session_info() if session.is_annotated)
-        True
+        Examples:
+
+            >>> next(session.is_annotated for session in get_session_info() if session.is_annotated)
+            True
         """
         if not self.is_sorted:
             return False
@@ -153,9 +232,11 @@ class SessionInfo:
         """Session metadata from Sam's DR training database.
         - empty dict for Templeton sessions
 
-        >>> next(get_session_info()).session_info                       # doctest: +SKIP
-        {'ID': 1, 'start_time': '2023-03-07 12:56:27', 'rig_name': 'B2', 'task_version': 'stage 0 moving', 'hits': '0', 'dprime_same_modality': '', 'dprime_other_modality_go_stim': '', 'pass': '1', 'ignore': '0'}
-        >>> assert next(session.training_info for session in get_session_info() if session.training_info)
+        Examples:
+
+            >>> next(get_session_info()).session_info                       # doctest: +SKIP
+            {'ID': 1, 'start_time': '2023-03-07 12:56:27', 'rig_name': 'B2', 'task_version': 'stage 0 moving', 'hits': '0', 'dprime_same_modality': '', 'dprime_other_modality_go_stim': '', 'pass': '1', 'ignore': '0'}
+            >>> assert next(session.training_info for session in get_session_info() if session.training_info)
         """
         return next(
             (
@@ -172,11 +253,21 @@ class SessionInfo:
     @functools.cached_property
     def is_templeton(self) -> bool:
         """Uses project in `tracked_sessions.yaml` if available, then infers from whether the session is in Sam's DR training
-        database."""
+        database.
+
+        Examples:
+            >>> get_session_info("2023-05-15_09-50-06_662983").is_templeton
+            True
+            >>> get_session_info("DRpilot_644867_20230221").is_templeton
+            False
+        """
         if "templeton" in self.project.lower():
             return True
         # training_info not available for Templeton sessions:
-        return self.subject in behavior_sessions.get_sessions_from_training_db()
+        return self.subject not in (
+            behavior_sessions.get_subjects_from_training_db()
+            | behavior_sessions.get_subjects_from_training_db(nsb=True)
+        )
 
     @property
     def rig(self) -> str:
@@ -204,34 +295,49 @@ class SessionInfo:
         return self.id == other.id
 
 
-@typing.overload
-def get_session_info() -> tuple[SessionInfo, ...]:
-    ...
+class SessionFilterKwargs(TypedDict, total=False):
+    is_ephys: NotRequired[bool]
+    is_uploaded: NotRequired[bool]
+    is_sync: NotRequired[bool]
+    is_sorted: NotRequired[bool]
+    is_annotated: NotRequired[bool]
 
 
 @typing.overload
-def get_session_info(session: str | npc_session.SessionRecord) -> SessionInfo:
-    ...
+def get_session_info(
+    **session_filter_kwargs: Unpack[SessionFilterKwargs],
+) -> tuple[SessionInfo, ...]: ...
+
+
+@typing.overload
+def get_session_info(
+    session: str | npc_session.SessionRecord,
+    **session_filter_kwargs: Unpack[SessionFilterKwargs],
+) -> SessionInfo: ...
 
 
 def get_session_info(
     session: str | npc_session.SessionRecord | SessionInfo | None = None,
-    **bool_filter_kwargs: bool,
+    **session_filter_kwargs: Unpack[SessionFilterKwargs],
 ) -> tuple[SessionInfo, ...] | SessionInfo:
     """Quickly get a sequence of all tracked sessions.
 
-    Each object in the sequence has info about one session:
-    >>> sessions = get_session_info()
-    >>> sessions[0].__class__.__name__
-    'SessionInfo'
-    >>> sessions[0].is_ephys                    # doctest: +SKIP
-    True
-    >>> any(s for s in sessions if s.date.year < 2021)
-    False
+    Examples:
 
-    Pass a session str or SessionRecord to get the info for that session:
-    >>> info = get_session_info("DRpilot_667252_20230927")
-    >>> assert isinstance(info, SessionInfo)
+        Each object in the sequence has info about one session:
+        >>> sessions = get_session_info()
+        >>> sessions[0].__class__.__name__
+        'SessionInfo'
+        >>> sessions[0].is_ephys                    # doctest: +SKIP
+        True
+        >>> any(s for s in sessions if s.date.year < 2021)
+        False
+
+        Pass a session str or SessionRecord to get the info for that session:
+        >>> info = get_session_info("DRpilot_667252_20230927")
+        >>> assert isinstance(info, SessionInfo)
+        >>> info.is_templeton
+        False
     """
     if isinstance(session, SessionInfo):
         session = session.id
@@ -243,7 +349,7 @@ def get_session_info(
         filtered_sessions = (
             s
             for s in tracked_sessions
-            if all(getattr(s, k) == v for k, v in bool_filter_kwargs.items())
+            if all(getattr(s, k) == v for k, v in session_filter_kwargs.items())
         )
         return tuple(sorted(filtered_sessions, key=lambda s: s.id.date, reverse=True))
     with contextlib.suppress(StopIteration):
@@ -256,13 +362,11 @@ def get_session_info(
 
 
 @typing.overload
-def get_session_issues() -> dict[npc_session.SessionRecord, list[str]]:
-    ...
+def get_session_issues() -> dict[npc_session.SessionRecord, list[str]]: ...
 
 
 @typing.overload
-def get_session_issues(session: str | npc_session.SessionRecord) -> list[str]:
-    ...
+def get_session_issues(session: str | npc_session.SessionRecord) -> list[str]: ...
 
 
 def get_session_issues(
@@ -270,17 +374,19 @@ def get_session_issues(
 ) -> list[str] | list | dict[npc_session.SessionRecord, list[str]]:
     """Get a dictionary of all sessions with issues mapped to their issue url.
 
-    >>> issues = get_session_issues()
-    >>> issues                                                              # doctest: +SKIP
-    {
-        '644867_2023-02-21': ['https://github.com/AllenInstitute/npc_sessions/issues/28'],
-        '660023_2023-08-08': ['https://github.com/AllenInstitute/npc_sessions/issues/26'],
-    }
+    Examples:
 
-    >>> single_session_issues = get_session_issues("DRPilot_644867_20230221")
-    >>> assert isinstance(single_session_issues, typing.Sequence)
-    >>> single_session_issues                                               # doctest: +SKIP
-    ['https://github.com/AllenInstitute/npc_sessions/issues/28']
+        >>> issues = get_session_issues()
+        >>> issues                                                              # doctest: +SKIP
+        {
+            '644867_2023-02-21': ['https://github.com/AllenInstitute/npc_sessions/issues/28'],
+            '660023_2023-08-08': ['https://github.com/AllenInstitute/npc_sessions/issues/26'],
+        }
+
+        >>> single_session_issues = get_session_issues("DRPilot_644867_20230221")
+        >>> assert isinstance(single_session_issues, typing.Sequence)
+        >>> single_session_issues                                               # doctest: +SKIP
+        ['https://github.com/AllenInstitute/npc_sessions/issues/28']
     """
     if session:
         try:
@@ -293,13 +399,11 @@ def get_session_issues(
 
 
 @typing.overload
-def get_session_kwargs() -> dict[npc_session.SessionRecord, dict]:
-    ...
+def get_session_kwargs() -> dict[npc_session.SessionRecord, dict]: ...
 
 
 @typing.overload
-def get_session_kwargs(session: str | npc_session.SessionRecord) -> dict[str, Any]:
-    ...
+def get_session_kwargs(session: str | npc_session.SessionRecord) -> dict[str, Any]: ...
 
 
 def get_session_kwargs(
@@ -308,21 +412,23 @@ def get_session_kwargs(
     """Get a dictionary of all sessions mapped to their config kwargs. kwargs will
     be an empty dict if no kwargs have been specified.
 
-    >>> kwargs = get_session_kwargs()
-    >>> kwargs                                                          # doctest: +SKIP
-    {   '670248_2023-08-02': {
-            'is_task': False,
-        },
-        '667252_2023-09-25': {
-            'invalid_times': [
-                {'start_time': 4996, 'stop_time': -1, 'reason': 'auditory stimulus not presented (amplifier power issue)'}
-            ]
-        },
-    }
-    >>> single_session_kwargs = get_session_kwargs("DRpilot_670248_20230802")
-    >>> assert isinstance(single_session_kwargs, dict)
-    >>> single_session_kwargs                                           # doctest: +SKIP
-    {'is_task': False}
+    Examples:
+
+        >>> kwargs = get_session_kwargs()
+        >>> kwargs                                                          # doctest: +SKIP
+        {   '670248_2023-08-02': {
+                'is_task': False,
+            },
+            '667252_2023-09-25': {
+                'invalid_times': [
+                    {'start_time': 4996, 'stop_time': -1, 'reason': 'auditory stimulus not presented (amplifier power issue)'}
+                ]
+            },
+        }
+        >>> single_session_kwargs = get_session_kwargs("DRpilot_670248_20230802")
+        >>> assert isinstance(single_session_kwargs, dict)
+        >>> single_session_kwargs                                           # doctest: +SKIP
+        {'is_task': False}
     """
     if session:
         try:
@@ -334,6 +440,8 @@ def get_session_kwargs(
 
 def _get_session_info_from_data_repo() -> Iterator[SessionInfo]:
     """
+    Examples:
+
     >>> session_info = next(_get_session_info_from_data_repo())
     """
     for subject, sessions in behavior_sessions.get_sessions_from_training_db().items():
@@ -351,7 +459,9 @@ def _get_session_info_from_file() -> tuple[SessionInfo, ...]:
     """Load yaml and parse sessions.
     - currently assumes all sessions include behavior data
 
-    >>> assert len(_get_session_info_from_file()) > 0
+    Examples:
+
+        >>> assert len(_get_session_info_from_file()) > 0
     """
     f = _session_info_from_file_contents
     if _TRACKED_SESSIONS_FILE.suffix == ".json":
